@@ -1,22 +1,8 @@
-/***************************************************************************
- *   This file is part of KDevelop                                         *
- *   Copyright 2013 Sven Brauch <svenbrauch@googlemail.com>                *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2013 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "correctionfilegenerator.h"
 
@@ -42,6 +28,12 @@
 #include <QStack>
 #include "codegendebug.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+#define SkipEmptyParts Qt::SkipEmptyParts
+#else
+#define SkipEmptyParts QString::SkipEmptyParts
+#endif
+
 using namespace KDevelop;
 
 namespace Python {
@@ -165,7 +157,7 @@ void TypeCorrection::accepted()
 
     CorrectionFileGenerator::HintType hintType = dialog->hintType();
 
-    generator.addHint(m_ui->typeText->text(), m_ui->importsText->text().split(',', QString::SkipEmptyParts), decl.data(), hintType);
+    generator.addHint(m_ui->typeText->text(), m_ui->importsText->text().split(',', SkipEmptyParts), decl.data(), hintType);
 
     qCDebug(KDEV_PYTHON_CODEGEN) << "Forcing a reparse on " << decl.data()->topContext()->url();
     ICore::self()->languageController()->backgroundParser()->addDocument(IndexedString(decl.data()->topContext()->url()),
