@@ -1,24 +1,8 @@
 /*
- * This file is part of kdev-python
- * Copyright 2013  Sven Brauch <svenbrauch@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2013 Sven Brauch <svenbrauch@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "docfilemanagerwidget.h"
 #include "kcm_docfiles.h"
@@ -40,7 +24,6 @@
 #include <QStandardPaths>
 #include <QDesktopServices>
 #include <QIcon>
-#include <QUrl>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -82,7 +65,7 @@ DocfileManagerWidget::DocfileManagerWidget(QWidget* parent)
     separator2->setFrameShape(QFrame::HLine);
     QPushButton* openFileManagerButton = new QPushButton(i18n("Open File Manager"));
     openFileManagerButton->setIcon(QIcon::fromTheme(QStringLiteral("system-file-manager")));
-    QPushButton* openTextEditorButton = new QPushButton(i18nc("Edit selected files", "Edit selected"));
+    QPushButton* openTextEditorButton = new QPushButton(i18nc("Edit selected files", "Edit Selected"));
     openTextEditorButton->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
     QPushButton* searchPathsButton = new QPushButton(i18n("Search Paths..."));
     searchPathsButton->setIcon(QIcon::fromTheme(QStringLiteral("search")));
@@ -108,6 +91,7 @@ DocfileManagerWidget::DocfileManagerWidget(QWidget* parent)
 
     setLayout(new QVBoxLayout);
     layout()->addWidget(splitter);
+    layout()->setContentsMargins(0, 0, 0, 0);
 }
 
 void DocfileManagerWidget::showSearchPaths()
