@@ -1,22 +1,11 @@
-/*****************************************************************************
- * Copyright (c) 2007 Andreas Pakulat <apaku@gmx.de>                         *
- * Copyright (c) 2007 Piyush verma <piyush.verma@gmail.com>                  *
- * Copyright (c) 2010-2013 Sven Brauch <svenbrauch@googlemail.com>           *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2007 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2007 Piyush verma <piyush.verma@gmail.com>
+    SPDX-FileCopyrightText: 2010-2013 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
+
 #include "pythonparsejob.h"
 
 #include "pythondebug.h"
@@ -47,7 +36,6 @@
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <interfaces/idocumentcontroller.h>
-#include <interfaces/iprojectcontroller.h>
 #include <util/foregroundlock.h>
 #include <project/projectmodel.h>
 #include <util/path.h>
@@ -55,7 +43,6 @@
 #include <ktexteditor/document.h>
 
 #include <QReadLocker>
-#include <QFile>
 #include <QThread>
 #include <QCoreApplication>
 #include <QProcess>
@@ -72,8 +59,8 @@ namespace Python
 
 ParseJob::ParseJob(const IndexedString &url, ILanguageSupport* languageSupport)
         : KDevelop::ParseJob(url, languageSupport)
-        , m_ast(0)
-        , m_duContext(0)
+        , m_ast(nullptr)
+        , m_duContext(nullptr)
 {
     IDefinesAndIncludesManager* iface = IDefinesAndIncludesManager::manager();
     auto project = ICore::self()->projectController()->findProjectForUrl(url.toUrl());
@@ -139,7 +126,7 @@ void ParseJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread* /*th
         }
     }
     
-    ReferencedTopDUContext toUpdate = 0;
+    ReferencedTopDUContext toUpdate = nullptr;
     {
         DUChainReadLocker lock;
         toUpdate = DUChainUtils::standardContextForUrl(document().toUrl());
@@ -198,8 +185,9 @@ void ParseJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread* /*th
             // this prevents infinite loops in case something goes wrong (optimally, shouldn't reach here if
             // the document was already rescheduled, but there's many cases where this might still happen)
             if ( ! ( minimumFeatures() & Rescheduled ) && dependencyInQueue ) {
+                constexpr TopDUContext::Features features{TopDUContext::ForceUpdate};
                 KDevelop::ICore::self()->languageController()->backgroundParser()->addDocument(document(),
-                                     static_cast<TopDUContext::Features>(TopDUContext::ForceUpdate | Rescheduled), parsePriority(),
+                                     static_cast<TopDUContext::Features>(features | Rescheduled), parsePriority(),
                                      nullptr, ParseJob::FullSequentialProcessing);
             }
         }
